@@ -15,6 +15,8 @@ except ImportError:
 
 __all__ = ["aer2ecef", "ecef2aer", "geodetic2aer", "aer2geodetic", "eci2aer", "aer2eci"]
 
+ELL = Ellipsoid.from_name("wgs84")
+
 
 def ecef2aer(
     x,
@@ -23,7 +25,7 @@ def ecef2aer(
     lat0,
     lon0,
     h0,
-    ell: Ellipsoid = None,
+    ell: Ellipsoid = ELL,
     deg: bool = True,
 ) -> tuple:
     """
@@ -72,7 +74,7 @@ def geodetic2aer(
     lat0,
     lon0,
     h0,
-    ell: Ellipsoid = None,
+    ell: Ellipsoid = ELL,
     deg: bool = True,
 ) -> tuple:
     """
@@ -120,7 +122,7 @@ def aer2geodetic(
     lat0,
     lon0,
     h0,
-    ell: Ellipsoid = None,
+    ell: Ellipsoid = ELL,
     deg: bool = True,
 ) -> tuple:
     """
@@ -213,7 +215,7 @@ def aer2eci(
     lon0,
     h0,
     t: datetime,
-    ell=None,
+    ell: Ellipsoid = ELL,
     *,
     deg: bool = True,
 ) -> tuple:
@@ -269,7 +271,7 @@ def aer2ecef(
     lat0,
     lon0,
     alt0,
-    ell: Ellipsoid = None,
+    ell: Ellipsoid = ELL,
     deg: bool = True,
 ) -> tuple:
     """
@@ -287,7 +289,7 @@ def aer2ecef(
            Observer geodetic latitude
     lon0 : float
            Observer geodetic longitude
-    h0 : float
+    alt0 : float
          observer altitude above geodetic ellipsoid (meters)
     ell : Ellipsoid, optional
           reference ellipsoid
