@@ -14,6 +14,8 @@ from .mathfun import atan2, cos, degrees, hypot, radians, sin
 
 __all__ = ["enu2aer", "aer2enu", "enu2geodetic", "geodetic2enu"]
 
+ELL = Ellipsoid.from_name("wgs84")
+
 
 def enu2aer(e, n, u, deg: bool = True) -> tuple:
     """
@@ -74,9 +76,9 @@ def aer2enu(az, el, srange, deg: bool = True) -> tuple:
 
     Parameters
     ----------
-    azimuth : float
+    az : float
             azimuth clockwise from north (degrees)
-    elevation : float
+    el : float
         elevation angle above horizon, neglecting aberrations (degrees)
     srange : float
         slant range [meters]
@@ -115,7 +117,7 @@ def enu2geodetic(
     lat0,
     lon0,
     h0,
-    ell: Ellipsoid = None,
+    ell: Ellipsoid = ELL,
     deg: bool = True,
 ) -> tuple:
     """
@@ -163,7 +165,7 @@ def geodetic2enu(
     lat0,
     lon0,
     h0,
-    ell: Ellipsoid = None,
+    ell: Ellipsoid = ELL,
     deg: bool = True,
 ) -> tuple:
     """
