@@ -22,8 +22,8 @@ from .mathfun import (
     sqrt,
     tan,
 )
-from .utils import sanitize
 
+ELL = Ellipsoid.from_name("wgs84")
 COS_EPS = 1e-9  # tolerance for angles near abs([90, 270])
 
 __all__ = [
@@ -47,7 +47,7 @@ __all__ = [
 def geoc2geod(
     geocentric_lat,
     geocentric_distance,
-    ell: Ellipsoid = None,
+    ell: Ellipsoid = ELL,
     deg: bool = True,
 ):
     """
@@ -78,7 +78,9 @@ def geoc2geod(
         and Geodetic Coordinates. Celestial Mechanics (12), 2, p. 225-230 (1975)
         doi: 10.1007/BF01230214"
     """
-    geocentric_lat, ell = sanitize(geocentric_lat, ell, deg)
+
+    if deg:
+        geocentric_lat = radians(geocentric_lat)
 
     r = geocentric_distance / ell.semimajor_axis
 
@@ -91,7 +93,7 @@ def geoc2geod(
     return degrees(geodetic_lat) if deg else geodetic_lat
 
 
-def geodetic2geocentric(geodetic_lat, alt_m, ell: Ellipsoid = None, deg: bool = True):
+def geodetic2geocentric(geodetic_lat, alt_m, ell: Ellipsoid = ELL, deg: bool = True):
     """
     convert geodetic latitude to geocentric latitude on spheroid surface
 
@@ -120,7 +122,10 @@ def geodetic2geocentric(geodetic_lat, alt_m, ell: Ellipsoid = None, deg: bool =
     US Geological Survey Professional Paper 1395, US Government Printing
     Office, Washington, DC, 1987, pp. 13-18.
     """
-    geodetic_lat, ell = sanitize(geodetic_lat, ell, deg)
+
+    if deg:
+        geodetic_lat = radians(geodetic_lat)
+
     r = rcurve.transverse(geodetic_lat, ell, deg=False)
     geocentric_lat = atan((1 - ell.eccentricity**2 * (r / (r + alt_m))) * tan(geodetic_lat))
 
@@ -130,7 +135,7 @@ def geodetic2geocentric(geodetic_lat, alt_m, ell: Ellipsoid = None, deg: bool =
 geod2geoc = geodetic2geocentric
 
 
-def geocentric2geodetic(geocentric_lat, alt_m, ell: Ellipsoid = None, deg: bool = True):
+def geocentric2geodetic(geocentric_lat, alt_m, ell: Ellipsoid = ELL, deg: bool = True):
     """
     converts from geocentric latitude to geodetic latitude
 
@@ -159,14 +164,17 @@ def geocentric2geodetic(geocentric_lat, alt_m, ell: Ellipsoid = None, deg: bool
     US Geological Survey Professional Paper 1395, US Government Printing
     Office, Washington, DC, 1987, pp. 13-18.
     """
-    geocentric_lat, ell = sanitize(geocentric_lat, ell, deg)
+
+    if deg:
+        geocentric_lat = radians(geocentric_lat)
+
     r = rcurve.transverse(geocentric_lat, ell, deg=False)
     geodetic_lat = atan(tan(geocentric_lat) / (1 - ell.eccentricity**2 * (r / (r + alt_m))))
 
     return degrees(geodetic_lat) if deg else geodetic_lat
 
 
-def geodetic2isometric(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
+def geodetic2isometric(geodetic_lat, ell: Ellipsoid = ELL, deg: bool = True):
     """
     computes isometric latitude on an ellipsoid
 
@@ -175,7 +183,7 @@ def geodetic2isometric(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
 
     Parameters
     ----------
-    lat : float
+    geodetic_lat : float
          geodetic latitude
     ell : Ellipsoid, optional
          reference ellipsoid (default WGS84)
@@ -196,7 +204,8 @@ def geodetic2isometric(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     January 2010
     """
 
-    geodetic_lat, ell = sanitize(geodetic_lat, ell, deg)
+    if deg:
+        geodetic_lat = radians(geodetic_lat)
 
     e = ell.eccentricity
 
@@ -226,7 +235,7 @@ def geodetic2isometric(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
         return isometric_lat
 
 
-def isometric2geodetic(isometric_lat, ell: Ellipsoid = None, deg: bool = True):
+def isometric2geodetic(isometric_lat, ell: Ellipsoid = ELL, deg: bool = True):
     """
     converts from isometric latitude to geodetic latitude
 
@@ -252,7 +261,7 @@ def isometric2geodetic(isometric_lat, ell: Ellipsoid = None, deg: bool = True):
     US Geological Survey Professional Paper 1395, US Government Printing
     Office, Washington, DC, 1987, pp. 13-18.
     """
-    # NOT sanitize for isometric2geo
+
     if deg:
         isometric_lat = radians(isometric_lat)
 
@@ -262,7 +271,7 @@ def isometric2geodetic(isometric_lat, ell: Ellipsoid = None, deg: bool = True):
     return degrees(geodetic_lat) if deg else geodetic_lat
 
 
-def conformal2geodetic(conformal_lat, ell: Ellipsoid = None, deg: bool = True):
+def conformal2geodetic(conformal_lat, ell: Ellipsoid = ELL, deg: bool = True):
     """
     converts from conformal latitude to geodetic latitude
 
@@ -288,7 +297,9 @@ def conformal2geodetic(conformal_lat, ell: Ellipsoid = None, deg: bool = True):
     US Geological Survey Professional Paper 1395, US Government Printing
     Office, Washington, DC, 1987, pp. 13-18.
     """
-    conformal_lat, ell = sanitize(conformal_lat, ell, deg)
+
+    if deg:
+        conformal_lat = radians(conformal_lat)
 
     e = ell.eccentricity
     f1 = e**2 / 2 + 5 * e**4 / 24 + e**6 / 12 + 13 * e**8 / 360
@@ -307,7 +318,7 @@ def conformal2geodetic(conformal_lat, ell: Ellipsoid = None, deg: bool = True):
     return degrees(geodetic_lat) if deg else geodetic_lat
 
 
-def geodetic2conformal(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
+def geodetic2conformal(geodetic_lat, ell: Ellipsoid = ELL, deg: bool = True):
     """
     converts from geodetic latitude to conformal latitude
 
@@ -335,7 +346,8 @@ def geodetic2conformal(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
 
     """
 
-    geodetic_lat, ell = sanitize(geodetic_lat, ell, deg)
+    if deg:
+        geodetic_lat = radians(geodetic_lat)
 
     e = ell.eccentricity
     f1 = 1 - e * sin(geodetic_lat)
@@ -355,7 +367,7 @@ def geodetic2conformal(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
 
 
 # %% rectifying
-def geodetic2rectifying(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
+def geodetic2rectifying(geodetic_lat, ell: Ellipsoid = ELL, deg: bool = True):
     """
     converts from geodetic latitude to rectifying latitude
 
@@ -382,7 +394,9 @@ def geodetic2rectifying(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     Office, Washington, DC, 1987, pp. 13-18.
 
     """
-    geodetic_lat, ell = sanitize(geodetic_lat, ell, deg)
+
+    if deg:
+        geodetic_lat = radians(geodetic_lat)
 
     n = ell.thirdflattening
     f1 = 3 * n / 2 - 9 * n**3 / 16
@@ -401,7 +415,7 @@ def geodetic2rectifying(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     return degrees(rectifying_lat) if deg else rectifying_lat
 
 
-def rectifying2geodetic(rectifying_lat, ell: Ellipsoid = None, deg: bool = True):
+def rectifying2geodetic(rectifying_lat, ell: Ellipsoid = ELL, deg: bool = True):
     """
     converts from rectifying latitude to geodetic latitude
 
@@ -427,7 +441,9 @@ def rectifying2geodetic(rectifying_lat, ell: Ellipsoid = None, deg: bool = True)
     US Geological Survey Professional Paper 1395, US Government Printing
     Office, Washington, DC, 1987, pp. 13-18.
     """
-    rectifying_lat, ell = sanitize(rectifying_lat, ell, deg)
+
+    if deg:
+        rectifying_lat = radians(rectifying_lat)
 
     n = ell.thirdflattening
     f1 = 3 * n / 2 - 27 * n**3 / 32
@@ -447,7 +463,7 @@ def rectifying2geodetic(rectifying_lat, ell: Ellipsoid = None, deg: bool = True)
 
 
 # %% authalic
-def geodetic2authalic(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
+def geodetic2authalic(geodetic_lat, ell: Ellipsoid = ELL, deg: bool = True):
     """
     converts from geodetic latitude to authalic latitude
 
@@ -474,7 +490,9 @@ def geodetic2authalic(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     Office, Washington, DC, 1987, pp. 13-18.
 
     """
-    geodetic_lat, ell = sanitize(geodetic_lat, ell, deg)
+
+    if deg:
+        geodetic_lat = radians(geodetic_lat)
 
     e = ell.eccentricity
     f1 = e**2 / 3 + 31 * e**4 / 180 + 59 * e**6 / 560
@@ -491,7 +509,7 @@ def geodetic2authalic(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     return degrees(authalic_lat) if deg else authalic_lat
 
 
-def authalic2geodetic(authalic_lat, ell: Ellipsoid = None, deg: bool = True):
+def authalic2geodetic(authalic_lat, ell: Ellipsoid = ELL, deg: bool = True):
     """
     converts from authalic latitude to geodetic latitude
 
@@ -517,7 +535,10 @@ def authalic2geodetic(authalic_lat, ell: Ellipsoid = None, deg: bool = True):
     US Geological Survey Professional Paper 1395, US Government Printing
     Office, Washington, DC, 1987, pp. 13-18.
     """
-    authalic_lat, ell = sanitize(authalic_lat, ell, deg)
+
+    if deg:
+        authalic_lat = radians(authalic_lat)
+
     e = ell.eccentricity
     f1 = e**2 / 3 + 31 * e**4 / 180 + 517 * e**6 / 5040
     f2 = 23 * e**4 / 360 + 251 * e**6 / 3780
@@ -534,7 +555,7 @@ def authalic2geodetic(authalic_lat, ell: Ellipsoid = None, deg: bool = True):
 
 
 # %% parametric
-def geodetic2parametric(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
+def geodetic2parametric(geodetic_lat, ell: Ellipsoid = ELL, deg: bool = True):
     """
     converts from geodetic latitude to parametric latitude
 
@@ -561,14 +582,16 @@ def geodetic2parametric(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     Office, Washington, DC, 1987, pp. 13-18.
 
     """
-    geodetic_lat, ell = sanitize(geodetic_lat, ell, deg)
+
+    if deg:
+        geodetic_lat = radians(geodetic_lat)
 
     parametric_lat = atan(sqrt(1 - (ell.eccentricity) ** 2) * tan(geodetic_lat))
 
     return degrees(parametric_lat) if deg else parametric_lat
 
 
-def parametric2geodetic(parametric_lat, ell: Ellipsoid = None, deg: bool = True):
+def parametric2geodetic(parametric_lat, ell: Ellipsoid = ELL, deg: bool = True):
     """
     converts from parametric latitude to geodetic latitude
 
@@ -594,7 +617,9 @@ def parametric2geodetic(parametric_lat, ell: Ellipsoid = None, deg: bool = True)
     US Geological Survey Professional Paper 1395, US Government Printing
     Office, Washington, DC, 1987, pp. 13-18.
     """
-    parametric_lat, ell = sanitize(parametric_lat, ell, deg)
+
+    if deg:
+        parametric_lat = radians(parametric_lat)
 
     geodetic_lat = atan(tan(parametric_lat) / sqrt(1 - (ell.eccentricity) ** 2))
 
