@@ -13,18 +13,20 @@ B = ELL.semiminor_axis
     "aer,lla,xyz", [((33, 70, 1000), (42, -82, 200), (660930.2, -4701424.0, 4246579.6))]
 )
 def test_aer2ecef(aer, lla, xyz):
-    x, y, z = pm.aer2ecef(*aer, *lla)
-    assert x == approx(xyz[0])
-    assert y == approx(xyz[1])
-    assert z == approx(xyz[2])
-    assert isinstance(x, float)
-    assert isinstance(y, float)
-    assert isinstance(z, float)
+    # degrees
+    xyz1 = pm.aer2ecef(*aer, *lla)
+    assert xyz1 == approx(xyz)
+    assert all(isinstance(n, float) for n in xyz1)
+    # float includes np.float64 i.e. a scalar
 
+    # radians
     raer = (radians(aer[0]), radians(aer[1]), aer[2])
     rlla = (radians(lla[0]), radians(lla[1]), lla[2])
-    assert pm.aer2ecef(*raer, *rlla, deg=False) == approx(xyz)
+    xyz1 = pm.aer2ecef(*raer, *rlla, deg=False)
+    assert xyz1 == approx(xyz)
+    assert all(isinstance(n, float) for n in xyz1)
 
+    # bad input
     with pytest.raises(ValueError):
         pm.aer2ecef(aer[0], aer[1], -1, *lla)
 
@@ -42,45 +44,57 @@ def test_aer2ecef(aer, lla, xyz):
     ],
 )
 def test_ecef2aer(xyz, lla, aer):
-    assert pm.ecef2aer(*xyz, *lla) == approx(aer)
+    # degrees
+    aer1 = pm.ecef2aer(*xyz, *lla)
+    assert aer1 == approx(aer)
+    assert all(isinstance(n, float) for n in aer1)
 
+    # radians
     rlla = (radians(lla[0]), radians(lla[1]), lla[2])
     raer = (radians(aer[0]), radians(aer[1]), aer[2])
-    assert pm.ecef2aer(*xyz, *rlla, deg=False) == approx(raer)
+    aer1 = pm.ecef2aer(*xyz, *rlla, deg=False)
+    assert aer1 == approx(raer)
+    assert all(isinstance(n, float) for n in aer1)
 
 
 @pytest.mark.parametrize("aer,enu", [((33, 70, 1000), (186.2775, 286.8422, 939.6926))])
 def test_aer_enu(aer, enu):
-    e, n, u = pm.aer2enu(*aer)
-    assert e == approx(enu[0])
-    assert n == approx(enu[1])
-    assert u == approx(enu[2])
-    assert isinstance(e, float)
-    assert isinstance(n, float)
-    assert isinstance(u, float)
+    # degrees
+    enu1 = pm.aer2enu(*aer)
+    assert enu1 == approx(enu)
+    assert all(isinstance(n, float) for n in enu1)
 
+    # radians
     raer = (radians(aer[0]), radians(aer[1]), aer[2])
-    assert pm.aer2enu(*raer, deg=False) == approx(enu)
+    enu1 = pm.aer2enu(*raer, deg=False)
+    assert enu1 == approx(enu)
+    assert all(isinstance(n, float) for n in enu1)
 
+    # bad input
     with pytest.raises(ValueError):
         pm.aer2enu(aer[0], aer[1], -1)
 
-    a, e, r = pm.enu2aer(*enu)
-    assert a == approx(aer[0])
-    assert e == approx(aer[1])
-    assert r == approx(aer[2])
-    assert isinstance(a, float)
-    assert isinstance(e, float)
-    assert isinstance(r, float)
+    # degrees
+    aer1 = pm.enu2aer(*enu)
+    assert aer1 == approx(aer)
+    assert all(isinstance(n, float) for n in aer1)
 
-    assert pm.enu2aer(*enu, deg=False) == approx(raer)
+    # radians
+    aer1 = pm.enu2aer(*enu, deg=False)
+    assert aer1 == approx(raer)
+    assert all(isinstance(n, float) for n in aer1)
 
 
 @pytest.mark.parametrize("aer,ned", [((33, 70, 1000), (286.8422, 186.2775, -939.6926))])
 def test_aer_ned(aer, ned):
-    assert pm.aer2ned(*aer) == approx(ned)
+    ned1 = pm.aer2ned(*aer)
+    assert ned1 == approx(ned)
+    assert all(isinstance(n, float) for n in ned1)
 
+    # bad value
     with pytest.raises(ValueError):
         pm.aer2ned(aer[0], aer[1], -1)
 
-    assert pm.ned2aer(*ned) == approx(aer)
+    aer1 = pm.ned2aer(*ned)
+    assert aer1 == approx(aer)
+    assert all(isinstance(n, float) for n in aer1)
