@@ -1,7 +1,13 @@
+from datetime import datetime
+
+import pymap3d as pm
 import pytest
 from pytest import approx
-from datetime import datetime
-import pymap3d as pm
+
+try:
+    import astropy
+except ImportError:
+    astropy = None
 
 
 def test_eci2ecef():
@@ -11,7 +17,8 @@ def test_eci2ecef():
     utc = datetime(2019, 1, 4, 12)
     ecef = pm.eci2ecef(*eci, utc)
 
-    rel = 0.0001
+    rel = 0.025 if astropy is None else 0.0001
+
     assert ecef == approx([-5.7627e6, -1.6827e6, 3.1560e6], rel=rel)
 
 
@@ -22,8 +29,9 @@ def test_ecef2eci():
     utc = datetime(2019, 1, 4, 12)
     eci = pm.ecef2eci(*ecef, utc)
 
-    rel = 0.0001
-    assert eci == approx([-2.9818e6, 5.2070e6, 3.1616e6], rel=rel)
+    rel = 0.01 if astropy is None else 0.0001
+
+    assert eci == approx([-2981810.6, 5207039.5, 3161595.1], rel=rel)
 
 
 def test_eci2geodetic():
@@ -33,46 +41,42 @@ def test_eci2geodetic():
     utc = datetime(2019, 1, 4, 12)
     lla = pm.eci2geodetic(*eci, utc)
 
-    rel = 0.0001
-    assert lla == approx([27.881, -163.722, 408850.65], rel=rel)
+    rel = 0.01 if astropy is None else 0.0001
+
+    assert lla == approx([27.880801, -163.722058, 408850.646], rel=rel)
 
 
 def test_geodetic2eci():
     pytest.importorskip("numpy")
 
-    lla = [27.881, -163.722, 408850.65]
+    lla = [27.880801, -163.722058, 408850.646]
     utc = datetime(2019, 1, 4, 12)
     eci = pm.geodetic2eci(*lla, utc)
 
-    rel = 0.0001
+    rel = 0.01 if astropy is None else 0.0001
+
     assert eci == approx([-2981784, 5207055, 3161595], rel=rel)
 
 
-def test_eci2aer():
+def test_eci_aer():
     # test coords from Matlab eci2aer
     pytest.importorskip("numpy")
-    t = datetime(1969, 7, 20, 21, 17, 40)
+    t = datetime(2022, 1, 2, 3, 4, 5)
 
-    eci = [-3.8454e8, -0.5099e8, -0.3255e8]
-    lla = [28.4, -80.5, 2.7]
+    eci = [4500000, -45000000, 3000000]
+    lla = [28, -80, 100]
 
     aer = pm.eci2aer(*eci, *lla, t)
-    rel = 0.0001
-    assert aer == approx([162.55, 55.12, 384013940.9], rel=rel)
 
+    rel = 0.01 if astropy is None else 0.0001
 
-def test_aer2eci():
-    # test coords from Matlab aer2eci
-    pytest.importorskip("numpy")
+    assert aer == approx([314.9945, -53.0089, 5.026e7], rel=rel)
 
-    aer = [162.55, 55.12, 384013940.9]
-    lla = [28.4, -80.5, 2.7]
-    t = datetime(1969, 7, 20, 21, 17, 40)
+    eci2 = pm.aer2eci(*aer, *lla, t)
 
-    eci = pm.aer2eci(*aer, *lla, t)
+    rel = 0.1 if astropy is None else 0.001
 
-    rel = 0.001
-    assert eci == approx([-3.8454e8, -0.5099e8, -0.3255e8], rel=rel)
+    assert eci2 == approx(eci, rel=rel)
 
     with pytest.raises(ValueError):
         pm.aer2eci(aer[0], aer[1], -1, *lla, t)
