@@ -1,10 +1,9 @@
+import pymap3d as pm
+import pymap3d.rcurve as rcurve
 import pytest
 from pytest import approx
 
-import pymap3d as pm
-import pymap3d.rcurve as rcurve
-
-ell = pm.Ellipsoid()
+ell = pm.Ellipsoid.from_name("wgs84")
 A = ell.semimajor_axis
 
 
