@@ -15,12 +15,6 @@ def test_geocentric_radius():
     assert rcurve.geocentric_radius(30) == approx(6372824.0)
 
 
-@pytest.mark.parametrize("bad_lat", [-91, 91])
-def test_geocentric_radius_badval(bad_lat):
-    with pytest.raises(ValueError):
-        rcurve.geocentric_radius(bad_lat)
-
-
 def test_rsphere_eqavol():
     assert rsphere.eqavol() == approx(6371000.8049)
 
